# Title
This library helps multiple data packs manage title & subtitle by aggregating usage by priority. This allows persistent messages to display without interrupting more urgent notification type messages.

## Usage
For usage information, see the [documentation](https://wiki.smithed.dev/libraries/smithed-core)
## Downloading
You can download this library from [the website](https://smithed.dev/packs/smithed/title)  
or  
You can build it from source using [beet](https://github.com/mcbeet/beet)

